@@ -63,6 +63,9 @@ class JavaScriptExtractor(BaseExtractor):
         source_code: str,
     ) -> ParseResult:
         """Extract entities and relations from JavaScript AST."""
+        # Set source bytes for correct byte offset handling
+        self._set_source(source_code)
+
         entities: list[Entity] = []
         relations: list[Relation] = []
 
