@@ -17,29 +17,30 @@ from mcp.server.stdio import stdio_server
 from codegraph_mcp.config import Config
 from codegraph_mcp.utils.logging import get_logger
 
+
 logger = get_logger(__name__)
 
 
 def create_server(config: Config) -> Server:
     """
     Create and configure the MCP server.
-    
+
     Args:
         config: Server configuration
-        
+
     Returns:
         Configured MCP server instance
     """
     server = Server("codegraph-mcp")
-    
+
     # Import handlers to register tools, resources, and prompts
-    from codegraph_mcp.mcp import tools, resources, prompts
-    
+    from codegraph_mcp.mcp import prompts, resources, tools
+
     # Register MCP components
     tools.register(server, config)
     resources.register(server, config)
     prompts.register(server, config)
-    
+
     return server
 
 
@@ -50,61 +51,68 @@ async def run_server_async(
 ) -> int:
     """
     Run the MCP server asynchronously.
-    
+
     Args:
         repo_path: Path to the repository to serve
         transport: Transport protocol ("stdio" or "sse")
         port: Port for SSE transport
-        
+
     Returns:
         Exit code (0 for success)
     """
+    from codegraph_mcp.core.engine_manager import shutdown_all
+
     config = Config(repo_path=repo_path)
     server = create_server(config)
-    
+
     logger.info(f"Starting CodeGraph MCP Server for {repo_path}")
     logger.info(f"Transport: {transport}")
-    
-    if transport == "stdio":
-        async with stdio_server() as (read_stream, write_stream):
-            await server.run(
-                read_stream,
-                write_stream,
-                server.create_initialization_options(),
-            )
-    elif transport == "sse":
-        # SSE transport implementation (REQ-TRP-003)
-        from mcp.server.sse import SseServerTransport
-        from starlette.applications import Starlette
-        from starlette.responses import Response
-        from starlette.routing import Mount, Route
-        import uvicorn
-        
-        sse = SseServerTransport("/messages/")
-        
-        async def handle_sse(request: Any) -> Response:
-            async with sse.connect_sse(
-                request.scope, request.receive, request._send
-            ) as streams:
+
+    try:
+        if transport == "stdio":
+            async with stdio_server() as (read_stream, write_stream):
                 await server.run(
-                    streams[0],
-                    streams[1],
+                    read_stream,
+                    write_stream,
                     server.create_initialization_options(),
                 )
-            return Response()
-        
-        app = Starlette(
-            routes=[
-                Route("/sse", endpoint=handle_sse),
-                Mount("/messages/", app=sse.handle_post_message),
-            ]
-        )
-        
-        logger.info(f"SSE server running on port {port}")
-        config = uvicorn.Config(app, host="0.0.0.0", port=port, log_level="info")
-        server_instance = uvicorn.Server(config)
-        await server_instance.serve()
-    
+        elif transport == "sse":
+            # SSE transport implementation (REQ-TRP-003)
+            import uvicorn
+            from mcp.server.sse import SseServerTransport
+            from starlette.applications import Starlette
+            from starlette.responses import Response
+            from starlette.routing import Mount, Route
+
+            sse = SseServerTransport("/messages/")
+
+            async def handle_sse(request: Any) -> Response:
+                async with sse.connect_sse(
+                    request.scope, request.receive, request._send
+                ) as streams:
+                    await server.run(
+                        streams[0],
+                        streams[1],
+                        server.create_initialization_options(),
+                    )
+                return Response()
+
+            app = Starlette(
+                routes=[
+                    Route("/sse", endpoint=handle_sse),
+                    Mount("/messages/", app=sse.handle_post_message),
+                ]
+            )
+
+            logger.info(f"SSE server running on port {port}")
+            config = uvicorn.Config(app, host="0.0.0.0", port=port, log_level="info")
+            server_instance = uvicorn.Server(config)
+            await server_instance.serve()
+    finally:
+        # Clean up all engine connections on shutdown
+        logger.info("Shutting down engine connections...")
+        await shutdown_all()
+
     return 0
 
 
@@ -115,12 +123,12 @@ def run_server(
 ) -> int:
     """
     Run the MCP server (synchronous wrapper).
-    
+
     Args:
         repo_path: Path to the repository to serve
         transport: Transport protocol ("stdio" or "sse")
         port: Port for SSE transport
-        
+
     Returns:
         Exit code (0 for success)
     """
